use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006008
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Num
Str
datetime
merchantID
ip
cid
CVN
cvc
cvv
login
SOAPI
Bleue
Carta
Carte
Dankort
JAL
Santander
UATP
YYYY
timestamp
Overmeer
AVS
MerchantReferenceCode
env
WSDL
XSD
subclasses
auth
dcc
GüdTech
HostGator
faultstring
faultcode
Caleb
Cushing
xenoterracide
Carl
Carstenson
ccarstenson
Robert
Stone
robertstone
lib
Business
CyberSource
RequestPart
Service
Tax
Exception
UnableToDetectCardTypeCode
Role
Traceable
SOAPFault
NotACreditCard
Factory
Rule
Request
DCC
AuthReversal
Item
CreditCardInfo
Currency
PurchaseTotals
Response
Base
RequestIDisZero
Capture
MooseX
Types
AttributeIsRequiredNotToBeSet
ResponsePart
TaxReply
BusinessRules
DCCReply
ExpiredCard
AuthReply
Sale
ProcessorResponse
AuthCode
RequestDateTime
ForeignCurrency
Reply
Client
TaxService
BillTo
Credit
ReasonCode
FollowOnCredit
Message
Card
ElectronicVerification
Authorization
MessagePart
ItemsOrTotal
BillingInfo
ReconciliationID
Amount
StandAloneCredit
